[Libreoffice] [PATCH 2/4] Translate german comments
Martin Kepplinger
martinkepplinger at eml.cc
Mon Feb 28 06:48:06 PST 2011
This translates the german code comments of edtwin2.cxx and edtwin3.cxx to
english.
This is contributed under the terms of the MPL 1.1 / GPLv3+ / LGPLv3+ triple
license.
---
sw/source/ui/docvw/edtwin2.cxx | 18 +++++++++---------
sw/source/ui/docvw/edtwin3.cxx | 26 +++++++++++++-------------
2 files changed, 22 insertions(+), 22 deletions(-)
diff --git a/sw/source/ui/docvw/edtwin2.cxx b/sw/source/ui/docvw/edtwin2.cxx
index 54b8638..f6134e0 100644
--- a/sw/source/ui/docvw/edtwin2.cxx
+++ b/sw/source/ui/docvw/edtwin2.cxx
@@ -82,7 +82,7 @@
// <--
/*--------------------------------------------------------------------
- Beschreibung: KeyEvents
+ Description: KeyEvents
--------------------------------------------------------------------*/
static void lcl_GetRedlineHelp( const SwRedline& rRedl, String& rTxt, BOOL bBalloon )
{
@@ -313,7 +313,7 @@ void SwEditWin::RequestHelp(const HelpEvent &rEvt)
{
break;
}
- case RES_INPUTFLD: // BubbleHelp, da der Hinweis ggf ziemlich lang sein kann
+ case RES_INPUTFLD: // BubbleHelp, because the suggestion could be quite long
bBalloon = TRUE;
/* no break */
case RES_JUMPEDITFLD:
@@ -381,7 +381,7 @@ void SwEditWin::RequestHelp(const HelpEvent &rEvt)
Help::ShowBalloon( this, rEvt.GetMousePosPixel(), sTxt );
else
{
- // dann zeige die Hilfe mal an:
+ // the show the help
Rectangle aRect( aFldRect.SVRect() );
Point aPt( OutputToScreenPixel( LogicToPixel( aRect.TopLeft() )));
aRect.Left() = aPt.X();
@@ -445,7 +445,7 @@ void SwEditWin::RequestHelp(const HelpEvent &rEvt)
if ((pField = aVEvt.pURLField) != 0)
{
- // URL-Feld getroffen
+ // hit an URL field
if (pField)
{
pObj = aVEvt.pObj;
@@ -456,7 +456,7 @@ void SwEditWin::RequestHelp(const HelpEvent &rEvt)
}
if (bWeiter && eHit == SDRHIT_TEXTEDIT)
{
- // URL-Feld in zum Editieren ge?ffneten DrawText-Objekt suchen
+ // look for URL field in DrawText object that is opened for editing
OutlinerView* pOLV = pSdrView->GetTextEditOutlinerView();
const SvxFieldItem* pFieldItem;
@@ -519,15 +519,15 @@ void SwEditWin::Paint(const Rectangle& rRect)
if( pShadCrsr )
{
Rectangle aRect( pShadCrsr->GetRect());
- // liegt vollstaendig drin?
+ // fully resides inside?
if( rRect.IsInside( aRect ) )
// dann aufheben
delete pShadCrsr, pShadCrsr = 0;
else if( rRect.IsOver( aRect ))
{
- // liegt irgendwie drueber, dann ist alles ausserhalb geclippt
- // und wir muessen den "inneren Teil" am Ende vom Paint
- // wieder sichtbar machen. Sonst kommt es zu Paintfehlern!
+ // resides somewhat above, then everything is clipped outside
+ // and we have to make the "inner part" at the end of the
+ // Paint visible again. Otherwise Paint errors occur!
bPaintShadowCrsr = TRUE;
}
}
diff --git a/sw/source/ui/docvw/edtwin3.cxx b/sw/source/ui/docvw/edtwin3.cxx
index b8b0276..5164048 100644
--- a/sw/source/ui/docvw/edtwin3.cxx
+++ b/sw/source/ui/docvw/edtwin3.cxx
@@ -51,7 +51,7 @@
/*--------------------------------------------------------------------
- Beschreibung: Core-Notify
+ Description: Core-Notify
--------------------------------------------------------------------*/
@@ -65,7 +65,7 @@ void ScrollMDI( ViewShell* pVwSh, const SwRect &rRect,
}
/*--------------------------------------------------------------------
- Beschreibung: Docmdi - verschiebbar
+ Description: Docmdi - movable
--------------------------------------------------------------------*/
@@ -79,7 +79,7 @@ BOOL IsScrollMDI( ViewShell* pVwSh, const SwRect &rRect )
}
/*--------------------------------------------------------------------
- Beschreibung: Notify fuer Groessen-Aenderung
+ Description: Notify for size change
--------------------------------------------------------------------*/
@@ -97,7 +97,7 @@ void SizeNotify(ViewShell* pVwSh, const Size &rSize)
}
/*--------------------------------------------------------------------
- Beschreibung: Notify fuer Seitenzahl-Update
+ Description: Notify for page number update
--------------------------------------------------------------------*/
@@ -112,8 +112,8 @@ void PageNumNotify( ViewShell* pVwSh, USHORT nPhyNum, USHORT nVirtNum,
}
/******************************************************************************
* Methode : void FrameNotify( DocMDIBase *pWin, FlyMode eMode )
* Beschreibung:
******************************************************************************/
@@ -125,7 +125,7 @@ void FrameNotify( ViewShell* pVwSh, FlyMode eMode )
}
/*--------------------------------------------------------------------
- Beschreibung: Notify fuer Seitenzahl-Update
+ Description: Notify for page number update
--------------------------------------------------------------------*/
BOOL SwEditWin::RulerColumnDrag( const MouseEvent& rMEvt, BOOL bVerticalMode)
{
@@ -185,16 +185,16 @@ void SwEditWin::DataChanged( const DataChangedEvent& rDCEvt )
switch( rDCEvt.GetType() )
{
case DATACHANGED_SETTINGS:
- // ScrollBars neu anordnen bzw. Resize ausloesen, da sich
- // ScrollBar-Groesse geaendert haben kann. Dazu muss dann im
- // Resize-Handler aber auch die Groesse der ScrollBars aus
- // den Settings abgefragt werden.
+ // rearrange ScrollBars, respectively trigger resize, because
+ // the ScrollBar size can have change. For that, in the reset
+ // handler, the size of the ScrollBars also has to be queried
+ // from the settings.
if( rDCEvt.GetFlags() & SETTINGS_STYLE )
{
pSh->LockPaint();
bUnlockPaint = TRUE;
ViewShell::DeleteReplacementBitmaps();
- GetView().InvalidateBorder(); //Scrollbarbreiten
+ GetView().InvalidateBorder(); //Scrollbar work
}
break;
@@ -204,7 +204,7 @@ void SwEditWin::DataChanged( const DataChangedEvent& rDCEvt )
case DATACHANGED_FONTSUBSTITUTION:
pSh->LockPaint();
bUnlockPaint = TRUE;
- GetView().GetDocShell()->UpdateFontList(); //z.B. Druckerwechsel
+ GetView().GetDocShell()->UpdateFontList(); //e.g. printer change
break;
}
pSh->LockView( bViewWasLocked );
@@ -112,8 +112,8 @@ void PageNumNotify( ViewShell* pVwSh, USHORT nPhyNum, USHORT nVirtNum,
}
/******************************************************************************
- * Methode : void FrameNotify( DocMDIBase *pWin, FlyMode eMode )
- * Beschreibung:
+ * Method : void FrameNotify( DocMDIBase *pWin, FlyMode eMode )
+ * Description:
******************************************************************************/
--
1.7.1
More information about the LibreOffice
mailing list